==> mkclean-0.1.1.tar.bz2: mkclean-0.1.1/libebml2/ebmldate.c <==
/*
 * $Id: ebmldate.c 153 2010-05-03 06:12:40Z robux4 $
 * Copyright (c) 2008, Matroska Foundation
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *     * Redistributions of source code must retain the above copyright
 *       notice, this list of conditions and the following disclaimer.
 *     * Redistributions in binary form must reproduce the above copyright
 *       notice, this list of conditions and the following disclaimer in the
 *       documentation and/or other materials provided with the distribution.
 *     * Neither the name of the Matroska Foundation nor the
 *       names of its contributors may be used to endorse or promote products
 *       derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY The Matroska Foundation ``AS IS'' AND ANY
 * EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL The Matroska Foundation BE LIABLE FOR ANY
 * DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
#include "ebml/ebml.h"

datetime_t EBML_DateTime(const ebml_date *Element)
{
    assert(Node_IsPartOf(Element,EBML_DATE_CLASS));
    if (!Element->Base.bValueIsSet)
        return 0;
    return (datetime_t)Scale32(Element->Value,1,1000000000); // nanoseconds to seconds
}

err_t EBML_DateSetDateTime(ebml_date *Element, datetime_t Date)
{
    if (Date == INVALID_DATETIME_T)
        return ERR_INVALID_PARAM;
    Element->Value = Scale64(Date,1000000000,1); // seconds to nanoseconds
    Element->Base.bValueIsSet = 1;
    return ERR_NONE;
}

static bool_t ValidateSize(ebml_element *p)
{
    return (p->Size == 8 || p->Size == 0);
}

static err_t ReadData(ebml_date *Element, stream *Input, const ebml_parser_context *ParserContext, bool_t AllowDummyElt, int Scope)
{
    err_t Result;
    int Size;
    uint8_t Value[8];

    Element->Base.bValueIsSet = 0;

    if (Scope == SCOPE_NO_DATA)
        return ERR_NONE;

    if (Stream_Seek(Input,EBML_ElementPositionData((ebml_element*)Element),SEEK_SET)==INVALID_FILEPOS_T)
    {
        Result = ERR_READ;
        goto failed;
    }

    assert(Element->Base.Size<=8);
    Result = Stream_Read(Input,Value,(size_t)Element->Base.Size,NULL);
    if (Result != ERR_NONE)
        goto failed;

#ifdef IS_BIG_ENDIAN
    memcpy(&Element->Value,Value,Element->Base.Size);
#else
    Element->Value = 0;
    for (Size=0;Size<Element->Base.Size;++Size)
        ((uint8_t*)&Element->Value)[Size] = Value[Element->Base.Size-Size-1];
#endif
    Element->Base.bValueIsSet = 1;
failed:
    return Result;
}

static void PostCreate(ebml_date *Element)
{
    INHERITED(Element,ebml_element_vmt,EBML_DATE_CLASS)->PostCreate(Element);
    Element->Base.DefaultSize = 8;
}

META_START(EBMLDate_Class,EBML_DATE_CLASS)
META_VMT(TYPE_FUNC,ebml_element_vmt,PostCreate,PostCreate)
META_VMT(TYPE_FUNC,ebml_element_vmt,ValidateSize,ValidateSize)
META_VMT(TYPE_FUNC,ebml_element_vmt,ReadData,ReadData)
META_END(EBML_SINTEGER_CLASS)

==> mkclean-0.1.3.tar.bz2: mkclean-0.1.3/libebml2/ebmldate.c <==
/*
 * $Id: ebmldate.c 171 2010-05-05 07:01:52Z robux4 $
 * Copyright (c) 2008, Matroska Foundation
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *     * Redistributions of source code must retain the above copyright
 *       notice, this list of conditions and the following disclaimer.
 *     * Redistributions in binary form must reproduce the above copyright
 *       notice, this list of conditions and the following disclaimer in the
 *       documentation and/or other materials provided with the distribution.
 *     * Neither the name of the Matroska Foundation nor the
 *       names of its contributors may be used to endorse or promote products
 *       derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY The Matroska Foundation ``AS IS'' AND ANY
 * EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL The Matroska Foundation BE LIABLE FOR ANY
 * DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
#include "ebml/ebml.h"

datetime_t EBML_DateTime(const ebml_date *Element)
{
    assert(Node_IsPartOf(Element,EBML_DATE_CLASS));
    if (!Element->Base.bValueIsSet)
        return 0;
    return (datetime_t)Scale32(Element->Value,1,1000000000); // nanoseconds to seconds
}

err_t EBML_DateSetDateTime(ebml_date *Element, datetime_t Date)
{
    if (Date == INVALID_DATETIME_T)
        return ERR_INVALID_PARAM;
    Element->Value = Scale64(Date,1000000000,1); // seconds to nanoseconds
    Element->Base.bValueIsSet = 1;
    return ERR_NONE;
}

static bool_t ValidateSize(ebml_element *p)
{
    return (p->DataSize == 8 || p->DataSize == 0);
}

static err_t ReadData(ebml_date *Element, stream *Input, const ebml_parser_context *ParserContext, bool_t AllowDummyElt, int Scope)
{
    err_t Result;
    int DataSize;
    uint8_t Value[8];

    Element->Base.bValueIsSet = 0;

    if (Scope == SCOPE_NO_DATA)
        return ERR_NONE;

    if (Stream_Seek(Input,EBML_ElementPositionData((ebml_element*)Element),SEEK_SET)==INVALID_FILEPOS_T)
    {
        Result = ERR_READ;
        goto failed;
    }

    assert(Element->Base.DataSize<=8);
    Result = Stream_Read(Input,Value,(size_t)Element->Base.DataSize,NULL);
    if (Result != ERR_NONE)
        goto failed;

#ifdef IS_BIG_ENDIAN
    memcpy(&Element->Value,Value,Element->Base.DataSize);
#else
    Element->Value = 0;
    for (DataSize=0;DataSize<Element->Base.DataSize;++DataSize)
        ((uint8_t*)&Element->Value)[DataSize] = Value[Element->Base.DataSize-DataSize-1];
#endif
    Element->Base.bValueIsSet = 1;
failed:
    return Result;
}

static void PostCreate(ebml_date *Element)
{
    INHERITED(Element,ebml_element_vmt,EBML_DATE_CLASS)->PostCreate(Element);
    Element->Base.DefaultSize = 8;
}

META_START(EBMLDate_Class,EBML_DATE_CLASS)
META_VMT(TYPE_FUNC,ebml_element_vmt,PostCreate,PostCreate)
META_VMT(TYPE_FUNC,ebml_element_vmt,ValidateSize,ValidateSize)
META_VMT(TYPE_FUNC,ebml_element_vmt,ReadData,ReadData)
META_END(EBML_SINTEGER_CLASS)
